@@ -1,5 +1,5 @@
 # coding: UTF-8
-'''Mock D-BUS objects for test suites.'''
+'''Mock D-Bus objects for test suites.'''
 
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -8,48 +8,87 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
 import copy
-import time
-import sys
-import types
-import importlib
 import imp
-from xml.etree import ElementTree
-
-# we do not use this ourselves, but mock methods often want to use this
+import importlib
 import os
-os  # pyflakes
+import sys
+import time
+import types
+from typing import Optional, Dict, Any, List, Tuple, Sequence, KeysView
+from xml.etree import ElementTree
 
 import dbus
 import dbus.service
 
+# we do not use this ourselves, but mock methods often want to use this
+os  # pyflakes pylint: disable=pointless-statement
+
 # global path -> DBusMockObject mapping
-objects = {}
+objects: Dict[str, 'DBusMockObject'] = {}
 
 MOCK_IFACE = 'org.freedesktop.DBus.Mock'
 OBJECT_MANAGER_IFACE = 'org.freedesktop.DBus.ObjectManager'
 
-# stubs to keep code compatible with Python 2 and 3
-if sys.version_info[0] >= 3:
-    long = int
-    unicode = str
+
+PropsType = Dict[str, Any]
+# (in_signature, out_signature, code, dbus_wrapper_fn)
+MethodType = Tuple[str, str, str, str]
+# (timestamp, method_name, call_args)
+CallLogType = Tuple[int, str, Sequence[Any]]
 
 
-def load_module(name):
+def load_module(name: str):
+    '''Load a mock template Python module from dbusmock/templates/'''
+
     if os.path.exists(name) and os.path.splitext(name)[1] == '.py':
         mod = imp.new_module(os.path.splitext(os.path.basename(name))[0])
         with open(name) as f:
-            exec(f.read(), mod.__dict__, mod.__dict__)
+            exec(f.read(), mod.__dict__, mod.__dict__)  # pylint: disable=exec-used
         return mod
 
     return importlib.import_module('dbusmock.templates.' + name)
 
 
-class DBusMockObject(dbus.service.Object):
+def _format_args(args):
+    '''Format a D-Bus argument tuple into an appropriate logging string'''
+
+    def format_arg(a):
+        if isinstance(a, dbus.Boolean):
+            return str(bool(a))
+        if isinstance(a, (dbus.Byte, int)):
+            return str(int(a))
+        if isinstance(a, str):
+            return '"' + str(a) + '"'
+        if isinstance(a, list):
+            return '[' + ', '.join([format_arg(x) for x in a]) + ']'
+        if isinstance(a, dict):
+            fmta = '{'
+            first = True
+            for k, v in a.items():
+                if first:
+                    first = False
+                else:
+                    fmta += ', '
+                fmta += format_arg(k) + ': ' + format_arg(v)
+            return fmta + '}'
+
+        # fallback
+        return repr(a)
+
+    s = ''
+    for a in args:
+        if s:
+            s += ' '
+        s += format_arg(a)
+    if s:
+        s = ' ' + s
+    return s
+
+
+class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-attributes
     '''Mock D-Bus object
 
     This can be configured to have arbitrary methods (including code execution)
@@ -57,8 +96,8 @@ class DBusMockObject(dbus.service.Object):
     that you can control the mock from any programming language.
     '''
 
-    def __init__(self, bus_name, path, interface, props, logfile=None,
-                 is_object_manager=False):
+    def __init__(self, bus_name: str, path: str, interface: str, props: PropsType,
+                 logfile: Optional[str] = None, is_object_manager: bool = False) -> None:
         '''Create a new DBusMockObject
 
         bus_name: A dbus.service.BusName instance where the object will be put on
@@ -69,7 +108,7 @@ class DBusMockObject(dbus.service.Object):
                properties on "interface"
         logfile: When given, method calls will be logged into that file name;
                  if None, logging will be written to stdout. Note that you can
-                 also query the called methods over D-BUS with GetCalls() and
+                 also query the called methods over D-Bus with GetCalls() and
                  GetMethodCalls().
         is_object_manager: If True, the GetManagedObjects method will
                            automatically be implemented on the object, returning
@@ -84,28 +123,25 @@ class DBusMockObject(dbus.service.Object):
         self.path = path
         self.interface = interface
         self.is_object_manager = is_object_manager
-        self.object_manager = None
+        self.object_manager: Optional[DBusMockObject] = None
 
-        self._template = None
-        self._template_parameters = None
+        self._template: Optional[str] = None
+        self._template_parameters: Optional[PropsType] = None
 
-        if logfile:
-            self.logfile = open(logfile, 'wb')
-        else:
-            self.logfile = None
+        self.logfile = open(logfile, 'wb') if logfile else None
         self.is_logfile_owner = True
-        self.call_log = []
+        self.call_log: List[CallLogType] = []
 
         if props is None:
             props = {}
 
         self._reset(props)
 
-    def __del__(self):
+    def __del__(self) -> None:
         if self.logfile and self.is_logfile_owner:
             self.logfile.close()
 
-    def _set_up_object_manager(self):
+    def _set_up_object_manager(self) -> None:
         '''Set up this mock object as a D-Bus ObjectManager.'''
         if self.path == '/':
             cond = 'k != \'/\''
@@ -118,19 +154,19 @@ class DBusMockObject(dbus.service.Object):
                        '  for k in objects.keys() if ' + cond + '}')
         self.object_manager = self
 
-    def _reset(self, props):
+    def _reset(self, props: PropsType) -> None:
         # interface -> name -> value
         self.props = {self.interface: props}
 
         # interface -> name -> (in_signature, out_signature, code, dbus_wrapper_fn)
-        self.methods = {self.interface: {}}
+        self.methods: Dict[str, Dict[str, MethodType]] = {self.interface: {}}
 
         if self.is_object_manager:
             self._set_up_object_manager()
 
     @dbus.service.method(dbus.PROPERTIES_IFACE,
                          in_signature='ss', out_signature='v')
-    def Get(self, interface_name, property_name):
+    def Get(self, interface_name: str, property_name: str) -> Any:
         '''Standard D-Bus API for getting a property value'''
 
         self.log('Get %s.%s' % (interface_name, property_name))
@@ -139,14 +175,14 @@ class DBusMockObject(dbus.service.Object):
             interface_name = self.interface
         try:
             return self.GetAll(interface_name)[property_name]
-        except KeyError:
+        except KeyError as e:
             raise dbus.exceptions.DBusException(
                 'no such property ' + property_name,
-                name=self.interface + '.UnknownProperty')
+                name=self.interface + '.UnknownProperty') from e
 
     @dbus.service.method(dbus.PROPERTIES_IFACE,
                          in_signature='s', out_signature='a{sv}')
-    def GetAll(self, interface_name, *args, **kwargs):
+    def GetAll(self, interface_name: str, *_, **__) -> PropsType:
         '''Standard D-Bus API for getting all property values'''
 
         self.log('GetAll ' + interface_name)
@@ -155,26 +191,26 @@ class DBusMockObject(dbus.service.Object):
             interface_name = self.interface
         try:
             return self.props[interface_name]
-        except KeyError:
+        except KeyError as e:
             raise dbus.exceptions.DBusException(
                 'no such interface ' + interface_name,
-                name=self.interface + '.UnknownInterface')
+                name=self.interface + '.UnknownInterface') from e
 
     @dbus.service.method(dbus.PROPERTIES_IFACE,
                          in_signature='ssv', out_signature='')
-    def Set(self, interface_name, property_name, value, *args, **kwargs):
+    def Set(self, interface_name: str, property_name: str, value: Any, *_, **__) -> None:
         '''Standard D-Bus API for setting a property value'''
 
         self.log('Set %s.%s%s' % (interface_name,
                                   property_name,
-                                  self.format_args((value,))))
+                                  _format_args((value,))))
 
         try:
             iface_props = self.props[interface_name]
-        except KeyError:
+        except KeyError as e:
             raise dbus.exceptions.DBusException(
                 'no such interface ' + interface_name,
-                name=self.interface + '.UnknownInterface')
+                name=self.interface + '.UnknownInterface') from e
 
         if property_name not in iface_props:
             raise dbus.exceptions.DBusException(
@@ -194,7 +230,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='ssa{sv}a(ssss)',
                          out_signature='')
-    def AddObject(self, path, interface, properties, methods):
+    def AddObject(self, path: str, interface: str, properties: PropsType, methods: List[MethodType]) -> None:
         '''Add a new D-Bus object to the mock
 
         path: D-Bus object path
@@ -243,7 +279,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='s',
                          out_signature='')
-    def RemoveObject(self, path):
+    def RemoveObject(self, path: str) -> None:  # pylint: disable=no-self-use
         '''Remove a D-Bus object from the mock
 
         As with AddObject, this will *not* emit the InterfacesRemoved signal if
@@ -252,14 +288,14 @@ class DBusMockObject(dbus.service.Object):
         try:
             objects[path].remove_from_connection()
             del objects[path]
-        except KeyError:
+        except KeyError as e:
             raise dbus.exceptions.DBusException(
                 'object %s does not exist' % path,
-                name='org.freedesktop.DBus.Mock.NameError')
+                name='org.freedesktop.DBus.Mock.NameError') from e
 
     @dbus.service.method(MOCK_IFACE,
                          in_signature='', out_signature='')
-    def Reset(self):
+    def Reset(self) -> None:
         '''Reset the mock object state.
 
         Remove all mock objects from the bus and tidy up so the state is as if
@@ -293,7 +329,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sssss',
                          out_signature='')
-    def AddMethod(self, interface, name, in_sig, out_sig, code):
+    def AddMethod(self, interface, name: str, in_sig: str, out_sig: str, code: str) -> None:
         '''Add a method to this object
 
         interface: D-Bus interface to add this to. For convenience you can
@@ -321,6 +357,8 @@ class DBusMockObject(dbus.service.Object):
               When specifying '', the method will not do anything (except
               logging) and return None.
         '''
+        # pylint: disable=protected-access
+
         if not interface:
             interface = self.interface
         n_args = len(dbus.Signature(in_sig))
@@ -350,7 +388,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sa(ssss)',
                          out_signature='')
-    def AddMethods(self, interface, methods):
+    def AddMethods(self, interface: str, methods: List[MethodType]) -> None:
         '''Add several methods to this object
 
         interface: D-Bus interface to add this to. For convenience you can
@@ -365,7 +403,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='ssv',
                          out_signature='')
-    def AddProperty(self, interface, name, value):
+    def AddProperty(self, interface: str, name: str, value: Any) -> None:
         '''Add property to this object
 
         interface: D-Bus interface to add this to. For convenience you can
@@ -376,19 +414,15 @@ class DBusMockObject(dbus.service.Object):
         '''
         if not interface:
             interface = self.interface
-        try:
-            self.props[interface][name]
+        if name in self.props.get(interface, {}):
             raise dbus.exceptions.DBusException(
                 'property %s already exists' % name,
                 name=self.interface + '.PropertyExists')
-        except KeyError:
-            # this is what we expect
-            pass
 
         # copy.copy removes one level of variant-ness, which means that the
         # types get exported in introspection data correctly, but we can't do
         # this for container types.
-        if not (isinstance(value, dbus.Dictionary) or isinstance(value, dbus.Array)):
+        if not isinstance(value, (dbus.Dictionary, dbus.Array)):
             value = copy.copy(value)
 
         self.props.setdefault(interface, {})[name] = value
@@ -396,7 +430,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sa{sv}',
                          out_signature='')
-    def AddProperties(self, interface, properties):
+    def AddProperties(self, interface: str, properties: PropsType) -> None:
         '''Add several properties to this object
 
         interface: D-Bus interface to add this to. For convenience you can
@@ -410,7 +444,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sa{sv}',
                          out_signature='')
-    def AddTemplate(self, template, parameters):
+    def AddTemplate(self, template: str, parameters: PropsType) -> None:
         '''Load a template into the mock.
 
         python-dbusmock ships a set of standard mocks for common system
@@ -439,8 +473,9 @@ class DBusMockObject(dbus.service.Object):
         if hasattr(module, 'IS_OBJECT_MANAGER') and module.IS_OBJECT_MANAGER:
             self._set_up_object_manager()
 
-        # pick out all D-BUS service methods and add them to our interface
+        # pick out all D-Bus service methods and add them to our interface
         for symbol in dir(module):
+            # pylint: disable=protected-access
             fn = getattr(module, symbol)
             if ('_dbus_interface' in dir(fn) and ('_dbus_is_signal' not in dir(fn) or not fn._dbus_is_signal)):
                 # for dbus-python compatibility, add methods as callables
@@ -462,7 +497,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sssav',
                          out_signature='')
-    def EmitSignal(self, interface, name, signature, args):
+    def EmitSignal(self, interface: str, name: str, signature: str, args: List[Any]) -> None:
         '''Emit a signal from the object.
 
         interface: D-Bus interface to send the signal from. For convenience you
@@ -475,6 +510,7 @@ class DBusMockObject(dbus.service.Object):
         args: variant array with signal arguments; must match order and type in
               "signature"
         '''
+        # pylint: disable=protected-access
         if not interface:
             interface = self.interface
 
@@ -487,7 +523,7 @@ class DBusMockObject(dbus.service.Object):
         m.append(signature=signature, *args)
         args = m.get_args_list()
 
-        fn = lambda self, *args: self.log('emit %s.%s%s' % (interface, name, self.format_args(args)))
+        fn = lambda self, *args: self.log('emit %s.%s%s' % (interface, name, _format_args(args)))
         fn.__name__ = str(name)
         dbus_fn = dbus.service.signal(interface)(fn)
         dbus_fn._dbus_signature = signature
@@ -498,7 +534,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='',
                          out_signature='a(tsav)')
-    def GetCalls(self):
+    def GetCalls(self) -> List[CallLogType]:
         '''List all the logged calls since the last call to ClearCalls().
 
         Return a list of (timestamp, method_name, args_list) tuples.
@@ -508,7 +544,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='s',
                          out_signature='a(tav)')
-    def GetMethodCalls(self, method):
+    def GetMethodCalls(self, method: str) -> List[Tuple[int, Sequence[Any]]]:
         '''List all the logged calls of a particular method.
 
         Return a list of (timestamp, args_list) tuples.
@@ -518,7 +554,7 @@ class DBusMockObject(dbus.service.Object):
     @dbus.service.method(MOCK_IFACE,
                          in_signature='',
                          out_signature='')
-    def ClearCalls(self):
+    def ClearCalls(self) -> None:
         '''Empty the log of mock call signatures.'''
 
         self.call_log = []
@@ -531,21 +567,24 @@ class DBusMockObject(dbus.service.Object):
         that a particular method was called with particular arguments, as an
         alternative to reading the mock's log or GetCalls().
         '''
-        pass
 
-    def object_manager_emit_added(self, path):
+    def object_manager_emit_added(self, path: str) -> None:
+        '''Emit ObjectManager.InterfacesAdded signal'''
+
         if self.object_manager is not None:
             self.object_manager.EmitSignal(OBJECT_MANAGER_IFACE, 'InterfacesAdded',
                                            'oa{sa{sv}}', [dbus.ObjectPath(path),
                                                           objects[path].props])
 
-    def object_manager_emit_removed(self, path):
+    def object_manager_emit_removed(self, path: str) -> None:
+        '''Emit ObjectManager.InterfacesRemoved signal'''
+
         if self.object_manager is not None:
             self.object_manager.EmitSignal(OBJECT_MANAGER_IFACE, 'InterfacesRemoved',
                                            'oas', [dbus.ObjectPath(path),
                                                    objects[path].props])
 
-    def mock_method(self, interface, dbus_method, in_signature, *args, **kwargs):
+    def mock_method(self, interface: str, dbus_method: str, in_signature: str, *args, **_) -> Any:
         '''Master mock method.
 
         This gets "instantiated" in AddMethod(). Execute the code snippet of
@@ -562,7 +601,7 @@ class DBusMockObject(dbus.service.Object):
         m.append(signature=in_signature, *args)
         args = m.get_args_list()
 
-        self.log(dbus_method + self.format_args(args))
+        self.log(dbus_method + _format_args(args))
         self.call_log.append((int(time.time()), str(dbus_method), args))
         self.MethodCalled(dbus_method, args)
 
@@ -572,52 +611,15 @@ class DBusMockObject(dbus.service.Object):
         code = self.methods[interface][dbus_method][2]
         if code and isinstance(code, types.FunctionType):
             return code(self, *args)
-        elif code:
+        if code:
             loc = locals().copy()
-            exec(code, globals(), loc)
+            exec(code, globals(), loc)  # pylint: disable=exec-used
             if 'ret' in loc:
                 return loc['ret']
 
-    def format_args(self, args):
-        '''Format a D-BUS argument tuple into an appropriate logging string.'''
+        return None
 
-        def format_arg(a):
-            if isinstance(a, dbus.Boolean):
-                return str(bool(a))
-            if isinstance(a, dbus.Byte):
-                return str(int(a))
-            if isinstance(a, int) or isinstance(a, long):
-                return str(a)
-            if isinstance(a, str):
-                return '"' + str(a) + '"'
-            if isinstance(a, unicode):  # Python 2 only
-                return '"' + repr(a.encode('UTF-8'))[1:-1] + '"'
-            if isinstance(a, list):
-                return '[' + ', '.join([format_arg(x) for x in a]) + ']'
-            if isinstance(a, dict):
-                fmta = '{'
-                first = True
-                for k, v in a.items():
-                    if first:
-                        first = False
-                    else:
-                        fmta += ', '
-                    fmta += format_arg(k) + ': ' + format_arg(v)
-                return fmta + '}'
-
-            # fallback
-            return repr(a)
-
-        s = ''
-        for a in args:
-            if s:
-                s += ' '
-            s += format_arg(a)
-        if s:
-            s = ' ' + s
-        return s
-
-    def log(self, msg):
+    def log(self, msg: str) -> None:
         '''Log a message, prefixed with a timestamp.
 
         If a log file was specified in the constructor, it is written there,
@@ -635,20 +637,23 @@ class DBusMockObject(dbus.service.Object):
                          out_signature='s',
                          path_keyword='object_path',
                          connection_keyword='connection')
-    def Introspect(self, object_path, connection):
+    def Introspect(self, object_path: str, connection: dbus.connection.Connection) -> str:
         '''Return XML description of this object's interfaces, methods and signals.
 
         This wraps dbus-python's Introspect() method to include the dynamic
         methods and properties.
         '''
+        # _dbus_class_table is an indirect private member of dbus.service.Object that pylint fails to see
+        # pylint: disable=no-member
+
         # temporarily add our dynamic methods
         cls = self.__class__.__module__ + '.' + self.__class__.__name__
         orig_interfaces = self._dbus_class_table[cls]
 
         mock_interfaces = orig_interfaces.copy()
-        for interface, methods in self.methods.items():
+        for iface, methods in self.methods.items():
             for method in methods:
-                mock_interfaces.setdefault(interface, {})[method] = self.methods[interface][method][3]
+                mock_interfaces.setdefault(iface, {})[method] = self.methods[iface][method][3]
         self._dbus_class_table[cls] = mock_interfaces
 
         xml = dbus.service.Object.Introspect(self, object_path, connection)
@@ -686,7 +691,7 @@ class DBusMockObject(dbus.service.Object):
 
 # Overwrite dbus-python's _method_lookup(), as that offers no way to have the
 # same method name on different interfaces
-orig_method_lookup = dbus.service._method_lookup
+orig_method_lookup = dbus.service._method_lookup  # pylint: disable=protected-access
 
 
 def _dbusmock_method_lookup(obj, method_name, dbus_interface):
@@ -697,7 +702,7 @@ def _dbusmock_method_lookup(obj, method_name, dbus_interface):
         return orig_method_lookup(obj, method_name, dbus_interface)
 
 
-dbus.service._method_lookup = _dbusmock_method_lookup
+dbus.service._method_lookup = _dbusmock_method_lookup  # pylint: disable=protected-access
 
 
 #
@@ -705,13 +710,13 @@ dbus.service._method_lookup = _dbusmock_method_lookup
 #
 
 
-def get_objects():
+def get_objects() -> KeysView[str]:
     '''Return all existing object paths'''
 
     return objects.keys()
 
 
-def get_object(path):
+def get_object(path) -> DBusMockObject:
     '''Return object for a given object path'''
 
     return objects[path]
