@@ -12,12 +12,10 @@ like "CanSuspend" or the return value of Inhibit() in "parameters".
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2013 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import dbus
 import os
+import dbus
 
 from dbusmock import MOCK_IFACE, mockobject
 
@@ -84,7 +82,7 @@ def load(mock, parameters):
 @dbus.service.method(MAIN_IFACE,
                      in_signature='',
                      out_signature='a(uso)')
-def ListUsers(self):
+def ListUsers(_):
     users = []
     for k, obj in mockobject.objects.items():
         if '/user/' in k:
@@ -96,7 +94,7 @@ def ListUsers(self):
 @dbus.service.method(MAIN_IFACE,
                      in_signature='',
                      out_signature='a(susso)')
-def ListSessions(self):
+def ListSessions(_):
     sessions = []
     for k, obj in mockobject.objects.items():
         if '/session/' in k:
