@@ -1,4 +1,3 @@
-# coding: UTF-8
 '''unittest.TestCase convenience methods for DBusMocks'''
 
 # This program is free software; you can redistribute it and/or modify it under
@@ -8,18 +7,17 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
-__license__ = 'LGPL 3+'
 
-import time
-import sys
-import unittest
-import subprocess
-import signal
-import os
 import errno
+import os
+import signal
+import subprocess
+import sys
 import tempfile
+import time
+import unittest
+from typing import Tuple, Dict, Any
 
 import dbus
 
@@ -27,7 +25,7 @@ from dbusmock.mockobject import MOCK_IFACE, OBJECT_MANAGER_IFACE, load_module
 
 
 class DBusTestCase(unittest.TestCase):
-    '''Base class for D-BUS mock tests.
+    '''Base class for D-Bus mock tests.
 
     This provides some convenience API to start/stop local D-Buses, so that you
     can run a private local session and/or system bus to run mocks on.
@@ -39,16 +37,16 @@ class DBusTestCase(unittest.TestCase):
     system_bus_pid = None
 
     @classmethod
-    def start_session_bus(klass):
+    def start_session_bus(cls) -> None:
         '''Set up a private local session bus
 
         This gets stopped automatically in tearDownClass().
         '''
-        (DBusTestCase.session_bus_pid, addr) = klass.start_dbus()
+        (DBusTestCase.session_bus_pid, addr) = cls.start_dbus()
         os.environ['DBUS_SESSION_BUS_ADDRESS'] = addr
 
     @classmethod
-    def start_system_bus(klass):
+    def start_system_bus(cls) -> None:
         '''Set up a private local system bus
 
         This gets stopped automatically in tearDownClass().
@@ -72,25 +70,25 @@ class DBusTestCase(unittest.TestCase):
 </busconfig>
 ''')
             c.flush()
-            (DBusTestCase.system_bus_pid, addr) = klass.start_dbus(conf=c.name)
+            (DBusTestCase.system_bus_pid, addr) = cls.start_dbus(conf=c.name)
         os.environ['DBUS_SYSTEM_BUS_ADDRESS'] = addr
 
     @classmethod
-    def tearDownClass(klass):
+    def tearDownClass(cls) -> None:
         '''Stop private session/system buses'''
 
         if DBusTestCase.session_bus_pid is not None:
-            klass.stop_dbus(DBusTestCase.session_bus_pid)
+            cls.stop_dbus(DBusTestCase.session_bus_pid)
             del os.environ['DBUS_SESSION_BUS_ADDRESS']
             DBusTestCase.session_bus_pid = None
         if DBusTestCase.system_bus_pid is not None:
-            klass.stop_dbus(DBusTestCase.system_bus_pid)
+            cls.stop_dbus(DBusTestCase.system_bus_pid)
             del os.environ['DBUS_SYSTEM_BUS_ADDRESS']
             DBusTestCase.system_bus_pid = None
 
     @classmethod
-    def start_dbus(klass, conf=None):
-        '''Start a D-BUS daemon
+    def start_dbus(cls, conf: str = None) -> Tuple[int, str]:
+        '''Start a D-Bus daemon
 
         Return (pid, address) pair.
 
@@ -111,22 +109,21 @@ class DBusTestCase(unittest.TestCase):
             return (int(lines[0]), lines[1])
 
     @classmethod
-    def stop_dbus(klass, pid):
-        '''Stop a D-BUS daemon
+    def stop_dbus(cls, pid: int) -> None:
+        '''Stop a D-Bus daemon
 
         Normally you do not need to call this directly. When you use
         start_system_bus() and start_session_bus(), these buses are
         automatically stopped in tearDownClass().
         '''
         signal.signal(signal.SIGTERM, signal.SIG_IGN)
-        for timeout in range(50):
+        for _ in range(50):
             try:
                 os.kill(pid, signal.SIGTERM)
             except OSError as e:
                 if e.errno == errno.ESRCH:
                     break
-                else:
-                    raise
+                raise
             time.sleep(0.1)
         else:
             sys.stderr.write('ERROR: timed out waiting for bus process to terminate\n')
@@ -135,7 +132,7 @@ class DBusTestCase(unittest.TestCase):
         signal.signal(signal.SIGTERM, signal.SIG_DFL)
 
     @classmethod
-    def get_dbus(klass, system_bus=False):
+    def get_dbus(cls, system_bus: bool = False) -> dbus.Bus:
         '''Get dbus.bus.BusConnection() object
 
         This is preferrable to dbus.SystemBus() and dbus.SessionBus() as those
@@ -144,23 +141,21 @@ class DBusTestCase(unittest.TestCase):
         if system_bus:
             if os.environ.get('DBUS_SYSTEM_BUS_ADDRESS'):
                 return dbus.bus.BusConnection(os.environ['DBUS_SYSTEM_BUS_ADDRESS'])
-            else:
-                return dbus.SystemBus()
-        else:
-            if os.environ.get('DBUS_SESSION_BUS_ADDRESS'):
-                return dbus.bus.BusConnection(os.environ['DBUS_SESSION_BUS_ADDRESS'])
-            else:
-                return dbus.SessionBus()
+            return dbus.SystemBus()
+
+        if os.environ.get('DBUS_SESSION_BUS_ADDRESS'):
+            return dbus.bus.BusConnection(os.environ['DBUS_SESSION_BUS_ADDRESS'])
+        return dbus.SessionBus()
 
     @classmethod
-    def wait_for_bus_object(klass, dest, path, system_bus=False, timeout=50):
-        '''Wait for an object to appear on D-BUS
+    def wait_for_bus_object(cls, dest: str, path: str, system_bus: bool = False, timeout: int = 600):
+        '''Wait for an object to appear on D-Bus
 
-        Raise an exception if object does not appear within 5 seconds. You can
+        Raise an exception if object does not appear within one minute. You can
         change the timeout with the "timeout" keyword argument which specifies
         deciseconds.
         '''
-        bus = klass.get_dbus(system_bus)
+        bus = cls.get_dbus(system_bus)
 
         last_exc = None
         # we check whether the name is owned first, to avoid race conditions
@@ -177,18 +172,17 @@ class DBusTestCase(unittest.TestCase):
                     last_exc = e
                     if '.UnknownInterface' in str(e):
                         break
-                    pass
 
             timeout -= 1
             time.sleep(0.1)
         if timeout <= 0:
-            assert timeout > 0, 'timed out waiting for D-BUS object %s: %s' % (path, last_exc)
+            assert timeout > 0, 'timed out waiting for D-Bus object %s: %s' % (path, last_exc)
 
     @classmethod
-    def spawn_server(klass, name, path, interface, system_bus=False, stdout=None):
+    def spawn_server(cls, name: str, path: str, interface: str, system_bus: bool = False, stdout: int = None):
         '''Run a DBusMockObject instance in a separate process
 
-        The daemon will terminate automatically when the D-BUS that it connects
+        The daemon will terminate automatically when the D-Bus that it connects
         to goes down.  If that does not happen (e. g. you test on the actual
         system/session bus), you need to kill it manually.
 
@@ -207,19 +201,19 @@ class DBusTestCase(unittest.TestCase):
         daemon = subprocess.Popen(argv, stdout=stdout)
 
         # wait for daemon to start up
-        klass.wait_for_bus_object(name, path, system_bus)
+        cls.wait_for_bus_object(name, path, system_bus)
 
         return daemon
 
     @classmethod
-    def spawn_server_template(klass, template, parameters=None, stdout=None):
-        '''Run a D-BUS mock template instance in a separate process
+    def spawn_server_template(cls, template: str, parameters: Dict[str, Any] = None, stdout: int = None):
+        '''Run a D-Bus mock template instance in a separate process
 
-        This starts a D-BUS mock process and loads the given template with
+        This starts a D-Bus mock process and loads the given template with
         (optional) parameters into it. For details about templates see
         dbusmock.DBusMockObject.AddTemplate().
 
-        The daemon will terminate automatically when the D-BUS that it connects
+        The daemon will terminate automatically when the D-Bus that it connects
         to goes down.  If that does not happen (e. g. you test on the actual
         system/session bus), you need to kill it manually.
 
@@ -241,10 +235,10 @@ class DBusTestCase(unittest.TestCase):
         else:
             interface_name = module.MAIN_IFACE
 
-        daemon = klass.spawn_server(module.BUS_NAME, module.MAIN_OBJ,
-                                    interface_name, module.SYSTEM_BUS, stdout)
+        daemon = cls.spawn_server(module.BUS_NAME, module.MAIN_OBJ,
+                                  interface_name, module.SYSTEM_BUS, stdout)
 
-        bus = klass.get_dbus(module.SYSTEM_BUS)
+        bus = cls.get_dbus(module.SYSTEM_BUS)
         obj = bus.get_object(module.BUS_NAME, module.MAIN_OBJ)
         if not parameters:
             parameters = dbus.Dictionary({}, signature='sv')
@@ -252,13 +246,3 @@ class DBusTestCase(unittest.TestCase):
                         dbus_interface=MOCK_IFACE)
 
         return (daemon, obj)
-
-
-# Python 2 backwards compatibility
-if sys.version_info[0] < 3:
-    import re
-
-    def assertRegex(self, value, pattern):
-        if not re.search(pattern, value):
-            raise self.failureException('%r not found in %s' % (pattern, value))
-    DBusTestCase.assertRegex = assertRegex
